@@ -34,7 +34,7 @@
 (define-module (gnucash report balsheet-eg))
 (use-modules (gnucash main))
 (use-modules (gnucash gnc-module))
-(use-modules (gnucash app-utils))
+(use-modules (gnucash gettext))
 (use-modules (gnucash report eguile-gnc))
 (use-modules (gnucash report eguile-utilities))
 
@@ -474,7 +474,7 @@
     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
     ;;; accrec-related routines
     ;;;
-    ;;; The accrec record stucture (defined above) and the following
+    ;;; The accrec record structure (defined above) and the following
     ;;; routines provide the basis for easy access to accounts
     ;;; from the main part of the report
 
@@ -506,9 +506,12 @@
              (and opt-omit-zb-accts?)
                   ;(> (accrec-depth accrec) 1))
              ;; Reason 1: zero Imbalance a/c
-             (string-prefix? (_ "Imbalance") (xaccAccountGetName (accrec-account accrec)))
+             ;; The line break in the next expressions will suppress comments as translator comments.
+             (string-prefix?
+               (_ "Imbalance") (xaccAccountGetName (accrec-account accrec)))
              ;; Reason 2: zero Orphan a/c
-             (string-prefix? (_ "Orphan") (xaccAccountGetName (accrec-account accrec))))))
+             (string-prefix?
+               (_ "Orphan") (xaccAccountGetName (accrec-account accrec))))))
 
     (define (flattened-acc-depth acc)
       ;; Accounts deeper than required get moved to the requested depth
